/**
 * @copyright: 2023- Le Filament (<https://le-filament.com>)
 * @license: AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
 */
odoo.define("oacc_portal.oacc_datatable", function (require) {
    "use strict";

    const {loadJS} = require("@web/core/assets");
    const {loadCSS} = require("@web/core/assets");
    var publicWidget = require("web.public.widget");

    publicWidget.registry.OaccDatatable = publicWidget.Widget.extend({
        selector: ".table-datatable",

        willStart: async function () {
            await loadJS("/oacc_portal/static/src/lib/datatables/datatables.min.js");
            await loadCSS("/oacc_portal/static/src/lib/datatables/datatables.min.css");
        },

        /**
         * @override
         */
        start: function () {
            var self = this;
            var $table = this.$el;

            // Init table options
            var tableOptions = {
                searching: $table.data("searching"),
                ordering: $table.data("ordering"),
                paging: $table.data("paging"),
                info: $table.data("info"),
                language: {
                    decimal: ",",
                    thousands: " ",
                    emptyTable: "Aucune donnée dans le tableau",
                    info: "_START_ à _END_ sur _TOTAL_ entrées",
                    infoEmpty: "0 su 0 entries",
                    infoFiltered: "(filtré sur un total de _MAX_ entrées)",
                    lengthMenu: "_MENU_ par page",
                    loadingRecords: "Chargement...",
                    search: "Recherche : ",
                    zeroRecords: "Aucun résultat",
                    paginate: {
                        first: "Première",
                        last: "Dernière",
                        next: "Suivant",
                        previous: "Précédent",
                    },
                },
                initComplete: function () {
                    self.$el.fadeTo(200, 1);
                },
            };

            // Define column attributes
            if ($table.data("order")) {
                var order = JSON.parse($table.data("order").replace(/'/g, '"'));
                tableOptions.order = order;
            }

            // Define column attributes
            if ($table.data("columndefs")) {
                var columndefs = JSON.parse(
                    $table.data("columndefs").replace(/'/g, '"')
                );
                tableOptions.columnDefs = columndefs;
            }

            // Set column groups
            if ($table.data("groupColumn")) {
                var groupColumn = $table.data("groupColumn");
                tableOptions = {
                    ...tableOptions,
                    columnDefs: [{visible: false, targets: groupColumn}],
                    order: [[groupColumn, "asc"]],
                    displayLength: $table.data("pageLength"),
                    drawCallback: function (settings) {
                        var api = this.api();
                        var rows = api.rows({page: "current"}).nodes();
                        var last = null;
                        var colspan = settings.aoColumns.length - 1;

                        api.column(groupColumn, {page: "current"})
                            .data()
                            .each(function (group, i) {
                                if (last !== group) {
                                    $(rows)
                                        .eq(i)
                                        .before(
                                            '<tr class="group"><td colspan="' +
                                                colspan +
                                                '">' +
                                                group +
                                                "</td></tr>"
                                        );

                                    last = group;
                                }
                            });
                    },
                };
            }

            // Draw Datatable
            this.dataTable = $table.find("table").DataTable(tableOptions);

            return this._super.apply(this, arguments);
        },
    });
});
