# Copyright 2021- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)
from odoo import _, models
from odoo.exceptions import UserError


class PortalWizardUser(models.TransientModel):
    _inherit = "portal.wizard.user"

    def _send_email(self):
        """send notification email to a new portal user"""
        self.ensure_one()

        # determine subject and body in the portal user's language
        template = self.env.ref("oacc_portal.acc_mail_template_data_portal_welcome")
        if not template:
            raise UserError(
                _(
                    "Le modèle de mail 'Portail ACC : nouvel utilisateur'"
                    " n'a pas été trouvé"
                )
            )

        lang = self.user_id.sudo().lang
        partner = self.user_id.sudo().partner_id

        portal_url = partner.with_context(
            signup_force_type_in_url="", lang=lang
        )._get_signup_url_for_action()[partner.id]
        partner.signup_prepare()

        # Get operations name linked
        acc_op_ids = (
            self.env["acc.counter.period"]
            .search([("partner_id", "=", partner.id)])
            .mapped("acc_operation_id")
        )
        op_str = ""
        for op in acc_op_ids:
            if op_str:
                op_str += ", " + op.description
            else:
                op_str = op.description

        template.with_context(
            dbname=self._cr.dbname,
            portal_url=portal_url,
            list_op=op_str,
            lang=lang,
        ).send_mail(self.id, force_send=True)

        return True
